// Copyright (C) 2008 - 2010 - Michael Baudin

// dispmat_plotnew --
//   Displays a matrix of values with entries from A.
//   Returns a data structure which can be processed by dispmat_plotconf.
// newplot = dispmat_plotnew ( A );
// newplot = dispmat_plotnew ( A , figWidth );
// newplot = dispmat_plotnew ( A , figWidth , figHeight , titlestr );
function newplot = dispmat_plotnew ( varargin ) 
  [lhs,rhs]=argn();
  if ( rhs<1 & rhs>4 ) then
    errmsg = msprintf(gettext("%s: Unexpected number of input arguments : %d provided while 1 to 4 are expected."), "dispmat_plotnew", rhs);
    error(errmsg)
  end
  if ( lhs<>1 ) then
    errmsg = msprintf(gettext("%s: Unexpected number of output arguments : %d provided while 1 is expected."), "dispmat_plotnew", lhs);
    error(errmsg)
  end
  // Reading the optionnal input arguments
  A = varargin(1);
  if ( rhs>=2 ) then
    figWidth  = varargin(2);
  else
    figWidth  = 400; 
  end
  if ( rhs>=3 ) then
    figHeight  = varargin(3);
  else
    figHeight  = 400; 
  end
  if ( rhs>=4 ) then
    titlestr  = varargin(4);
  else
    titlestr  = "Matrix Content"; 
  end
  // Compute the number of rows, columns
  ncols = size(A,"c")
  nrows = size(A,"r")
  // Create the list of uicontrols
  // A(i,j) is represented by l((i-1)*n + j)
  newplot = tlist(["T_DMPLOT" 
    "figure" 
    "uicontrols"
    "A"
    ]);
  newplot.A = A
  cellWidth = figWidth / ncols
  cellHeight = figHeight / nrows
  fig=figure("Position",[10 10 figWidth figHeight]);
  fig.auto_resize = "off";
  set(fig,"figure_name",titlestr);
  newplot.figure = fig
  newplot.uicontrols = list()
  for i = 1 : nrows
    for j = 1 : ncols
      x = 0 + (j-1) * cellWidth
      y = figHeight - i * cellHeight
      h =uicontrol ( fig , ...
      "style" , "text" , ...
      "position" , [x y cellWidth cellHeight] , ...
      "BackgroundColor",[0.9 0.9 0.9], ...
      "Horizontalalignment","center",...
      "Relief" , "raised", ...
      "FontSize", 20, ...
      "String",string(A(i,j)) );
      newplot.uicontrols((i-1)*ncols + j) = h;
    end
  end
endfunction

